@@ -13,6 +13,7 @@ import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.EmptyStarTable;
 import uk.ac.starlink.table.JoinFixAction;
 import uk.ac.starlink.table.OnceRowPipe;
+import uk.ac.starlink.table.RowData;
 import uk.ac.starlink.table.RowListStarTable;
 import uk.ac.starlink.table.RowPipe;
 import uk.ac.starlink.table.RowSequence;
@@ -26,7 +27,7 @@ import uk.ac.starlink.ttools.filter.AddColumnsTable;
 import uk.ac.starlink.ttools.filter.CalculatorColumnSupplement;
 import uk.ac.starlink.ttools.filter.ColumnSupplement;
 import uk.ac.starlink.ttools.filter.PermutedColumnSupplement;
-import uk.ac.starlink.ttools.filter.SupplementSequence;
+import uk.ac.starlink.ttools.filter.SupplementData;
 import uk.ac.starlink.ttools.func.CoordsDegrees;
 import uk.ac.starlink.ttools.jel.ColumnIdentifier;
 import uk.ac.starlink.ttools.task.TableProducer;
@@ -808,8 +809,8 @@ public class ConeMatcher {
             return row_.clone();
         }
 
-        public SupplementSequence createSequence( RowSequence rseq ) {
-            return new SupplementSequence() {
+        public SupplementData createSupplementData( RowData rdata ) {
+            return new SupplementData() {
                 public Object getCell( long irow, int icol ) {
                     return row_[ icol ];
                 }
