@@ -23,6 +23,7 @@ import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.ttools.jel.JELTable;
 import uk.ac.starlink.ttools.task.InputTableSpec;
 import uk.ac.starlink.ttools.task.JoinFixActionParameter;
+import uk.ac.starlink.ttools.task.RowRunnerParameter;
 import uk.ac.starlink.ttools.task.TableMapper;
 import uk.ac.starlink.ttools.task.TableMapping;
 import uk.ac.starlink.ttools.task.WordsParameter;
@@ -114,7 +115,7 @@ public class MatchMapper implements TableMapper {
         matcherParam_ = new MatchEngineParameter( "matcher" );
         fixcolsParam_ = new JoinFixActionParameter( "fixcols" );
         progressParam_ = new ProgressIndicatorParameter( "progress" );
-        runnerParam_ = new MatchRunnerParameter( "runner" );
+        runnerParam_ = RowRunnerParameter.createMatchRunnerParameter( "runner");
     }
 
     public Parameter<?>[] getParameters() {
@@ -187,8 +188,8 @@ public class MatchMapper implements TableMapper {
         private final MatchEngine matchEngine_;
         private final String[][] exprTuples_;
         private final JoinFixAction[] fixActs_;
-        private final ProgressIndicator progger_;
-        private final RowRunner runner_;
+        final RowRunner runner_;
+        final ProgressIndicator progger_;
 
         /**
          * Constructor.
@@ -215,6 +216,23 @@ public class MatchMapper implements TableMapper {
 
         public StarTable mapTables( InputTableSpec[] inSpecs )
                 throws IOException, TaskException {
+            try {
+                return attemptMapTables( inSpecs );
+            }
+            catch ( InterruptedException e ) {
+                throw new ExecutionException( e.getMessage(), e );
+            }
+        }
+
+       /**
+        * Does the work for the mapTables method, but may throw an
+        * InterruptedException if the operations were forcibly terminated.
+        *
+        * @param  inSpecs  input table specifications
+        * @return  joined table
+        */
+        private StarTable attemptMapTables( InputTableSpec[] inSpecs )
+                throws IOException, TaskException, InterruptedException {
 
             /* Get the input tables and check for errors. */
             StarTable[] inTables = new StarTable[ nin_ ];
@@ -240,13 +258,7 @@ public class MatchMapper implements TableMapper {
             RowMatcher matcher =
                 RowMatcher.createMatcher( matchEngine_, subTables, runner_ );
             matcher.setIndicator( progger_ );
-            LinkSet matches;
-            try { 
-                matches = findMatches( matcher );
-            }
-            catch ( InterruptedException e ) {
-                throw new ExecutionException( e.getMessage(), e );
-            }
+            LinkSet matches = findMatches( matcher );
 
             /* Create a new table based on the matched rows. */
             Collection<RowLink> orderedMatches =
@@ -276,7 +288,7 @@ public class MatchMapper implements TableMapper {
                 createJoinTable( StarTable[] inTables,
                                  Collection<RowLink> matches,
                                  JoinFixAction[] fixActs )
-                throws IOException;
+                throws IOException, InterruptedException;
       
 
         /**
@@ -339,8 +351,9 @@ public class MatchMapper implements TableMapper {
 
         protected StarTable createJoinTable( StarTable[] inTables,
                                              Collection<RowLink> matches,
-                                             JoinFixAction[] fixActs ) {
-            return MatchStarTables
+                                             JoinFixAction[] fixActs )
+                throws InterruptedException {
+            return MatchStarTables.createInstance( progger_, runner_ )
                   .makeJoinTable( inTables, matches, false, fixActs, null );
         }
     }
@@ -379,8 +392,9 @@ public class MatchMapper implements TableMapper {
 
         protected StarTable createJoinTable( StarTable[] inTables,
                                              Collection<RowLink> matches,
-                                             JoinFixAction[] fixActs ) {
-            return MatchStarTables
+                                             JoinFixAction[] fixActs )
+                throws InterruptedException {
+            return MatchStarTables.createInstance( progger_, runner_ )
                   .makeJoinTable( inTables, matches, false, fixActs, null );
         }
     }
