@@ -18,8 +18,11 @@ import java.util.List;
 import java.util.zip.GZIPOutputStream;
 import javax.imageio.ImageIO;
 import javax.swing.JComponent;
+import org.jfree.graphics2d.svg.MeetOrSlice;
+import org.jfree.graphics2d.svg.PreserveAspectRatio;
 import org.jfree.graphics2d.svg.SVGGraphics2D;
 import org.jfree.graphics2d.svg.SVGUnits;
+import org.jfree.graphics2d.svg.ViewBox;
 import org.jibble.epsgraphics.EpsGraphics2D;
 
 /**
@@ -183,13 +186,28 @@ public abstract class GraphicExporter {
                                  new String[] { ".svg", } ) {
         public void exportGraphic( Picture picture, OutputStream out )
                 throws IOException {
-            SVGGraphics2D g2 =
-                new SVGGraphics2D( picture.getPictureWidth(),
-                                   picture.getPictureHeight(),
-                                   SVGUnits.PX );
+            int w = picture.getPictureWidth();
+            int h = picture.getPictureHeight();
+            SVGGraphics2D g2 = new SVGGraphics2D( w, h, SVGUnits.PX );
             picture.paintPicture( g2 );
             Writer writer = new OutputStreamWriter( out, "UTF-8" );
-            writer.write( g2.getSVGDocument() );
+
+            /* Export to suitable XML.  There are some subtleties in getting
+             * this right; following advice and experimentation, setting both
+             * the viewBox attribute and dimensions (width/height) attributes,
+             * with preserveAspectRatio left to defaults, seems to provide the
+             * right behaviour for default and rescaled image size in both
+             * IMG and OBJECT elements.  Output is to a single SVG element,
+             * undecorated by an XML or DOCTYPE declaration.
+             * These details are subject to change if expert SVG users decide
+             * they're doing the wrong thing. */
+            String id = null;
+            boolean includeDimensions = true;
+            ViewBox viewBox = new ViewBox( 0, 0, w, h );
+            PreserveAspectRatio aspect = null;
+            MeetOrSlice meet = null;
+            writer.write( g2.getSVGElement( id, includeDimensions, viewBox,
+                                            aspect, meet ) );
             writer.close();
         }
     };
