@@ -979,6 +979,16 @@ public class StyleKeys {
             clip( Shaders.LUT_GLNEMO2, c * 0.03, true ),
             clip( Shaders.LUT_RAINBOW3, 0, true ),
             clip( Shaders.LUT_PASTEL, c * 0.06, true ),
+            clip( Shaders.LUT_COSMIC, 0, true ),
+            clip( Shaders.LUT_EMBER, 0.05, true ),
+            clip( Shaders.LUT_GOTHIC, 0.15, true ),
+            clip( Shaders.LUT_RAINFOREST, 0.15, true ),
+            clip( Shaders.LUT_VOLTAGE, 0.15, true ),
+            clip( Shaders.LUT_BUBBLEGUM, 0, true ),
+            clip( Shaders.LUT_GEM, 0, true ),
+            clip( Shaders.LUT_CHROMA, 0.15, true ),
+            clip( Shaders.LUT_NEON, 0, true ),
+            clip( Shaders.LUT_TROPICAL, 0, true ),
             clip( Shaders.LUT_ACCENT, 0, true ),
             clip( Shaders.LUT_GNUPLOT, c * 0.1, true ),
             clip( Shaders.LUT_GNUPLOT2, c * 0.2, true ),
@@ -986,6 +996,10 @@ public class StyleKeys {
             clip( Shaders.LUT_SET1, 0, true ),
             clip( Shaders.LUT_PAIRED, 0, true ),
             clip( Shaders.LUT_HOTCOLD, 0, false ),
+            clip( Shaders.LUT_GUPPY, 0, false ),
+            clip( Shaders.LUT_ICEBURN, 0, false ),
+            clip( Shaders.LUT_REDSHIFT, 0, false ),
+            clip( Shaders.LUT_PRIDE, 0, false ),
             clip( Shaders.BREWER_RDBU, 0, false ),
             clip( Shaders.BREWER_PIYG, 0, false ),
             clip( Shaders.BREWER_BRBG, 0, false ),
@@ -1005,6 +1019,7 @@ public class StyleKeys {
             clip( Shaders.BREWER_PURD, c * 0.15, false ),
             clip( Shaders.LUT_PAINBOW, 0, false ),
             clip( Shaders.HCL_POLAR, 0, false ),
+            clip( Shaders.LUT_INFINITY, 0, false ),
             clip( Shaders.FIX_HUE, 0, false ),
             clip( Shaders.FIX_INTENSITY, 0, true ),
             clip( Shaders.FIX_RED, 0, false ),
