@@ -7,6 +7,8 @@ import java.util.function.Function;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.RowAccess;
+import uk.ac.starlink.table.RowData;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.ValueInfo;
@@ -51,18 +53,18 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
 
     public TupleSequence getTupleSequence( DataSpec spec ) {
         StarTable table = spec.getSourceTable();
-        if ( table.isRandom() && table.getRowCount() > 2 ) {
-            return new RandomSimpleTupleSequence( spec, table );
-        }
-        else {
-            try {
+        try {
+            if ( table.isRandom() && table.getRowCount() > 2 ) {
+                return new RandomSimpleTupleSequence( spec, table );
+            }
+            else {
                 RowSequence rseq = spec.getSourceTable().getRowSequence();
                 return new SequentialSimpleTupleSequence( spec, rseq );
             }
-            catch ( IOException e ) {
-                logger_.log( Level.WARNING, "Error reading plot data", e );
-                return PlotUtil.EMPTY_TUPLE_SEQUENCE;
-            }
+        }
+        catch ( IOException e ) {
+            logger_.log( Level.WARNING, "Error reading plot data", e );
+            return PlotUtil.EMPTY_TUPLE_SEQUENCE;
         }
     }
 
@@ -78,19 +80,22 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
     private static abstract class SimpleTupleSequence implements TupleSequence {
 
         final DataSpec spec_;
+        final RowData rowdata_;
         final UserDataReader reader_;
         final List<Function<Object[],?>> inputStorages_;
-        RowSequence rowseq_;
         long irow_;
         boolean failed_;
 
         /**
-         * Constructor.  Subclasses must initialise the rowseq_ member.
+         * Constructor.
          *
          * @param   spec  data specification
+         * @param   rowdata  row data object from which current row data
+         *                   is kept available
          */
-        SimpleTupleSequence( DataSpec spec ) {
+        SimpleTupleSequence( DataSpec spec, RowData rowdata ) {
             spec_ = spec;
+            rowdata_ = rowdata;
             reader_ = spec.createUserDataReader();
             inputStorages_ = new ArrayList<Function<Object[],?>>();
             for ( int ic = 0; ic < spec.getCoordCount(); ic++ ) {
@@ -109,7 +114,7 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
         public Object getObjectValue( int icol ) {
             try {
                 Object[] userCoords =
-                    reader_.getUserCoordValues( rowseq_, irow_, icol );
+                    reader_.getUserCoordValues( rowdata_, irow_, icol );
                 Object value = inputStorages_.get( icol ).apply( userCoords );
                 assert value != null;
                 return value;
@@ -155,6 +160,7 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
      */
     private static class SequentialSimpleTupleSequence
             extends SimpleTupleSequence {
+        private final RowSequence rseq_;
 
         /**
          * Constructor.
@@ -163,14 +169,14 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
          * @param   rseq  row sequence from spec's source table
          */
         SequentialSimpleTupleSequence( DataSpec spec, RowSequence rseq ) {
-            super( spec );
-            rowseq_ = rseq;
+            super( spec, rseq );
+            rseq_ = rseq;
         }
 
         public boolean next() {
             try {
-                while ( ! failed_ && rowseq_.next() ) {
-                    if ( reader_.getMaskFlag( rowseq_, ++irow_ ) ) {
+                while ( ! failed_ && rseq_.next() ) {
+                    if ( reader_.getMaskFlag( rseq_, ++irow_ ) ) {
                         return true;
                     }
                 }
@@ -179,7 +185,7 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
                 logError( e );
             }
             try {
-                rowseq_.close();
+                rseq_.close();
             }
             catch ( IOException e ) {
                 // ignore
@@ -203,6 +209,7 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
     private static class RandomSimpleTupleSequence extends SimpleTupleSequence {
 
         private final StarTable table_;
+        private final RowAccess racc_;
         private long nrow_;
 
         /**
@@ -211,7 +218,8 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
          * @param   spec  data specification
          * @param   table  source table
          */
-        RandomSimpleTupleSequence( DataSpec spec, StarTable table ) {
+        RandomSimpleTupleSequence( DataSpec spec, StarTable table )
+                throws IOException {
             this( spec, table, -1, table.getRowCount() );
         }
 
@@ -224,22 +232,10 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
          * @param   nrow   first index after iteration run
          */
         RandomSimpleTupleSequence( DataSpec spec, StarTable table,
-                                   long irow, long nrow ) {
-            super( spec );
-            rowseq_ = new RowSequence() {
-                public Object getCell( int icol ) throws IOException {
-                    return table_.getCell( irow_, icol );
-                }
-                public Object[] getRow() throws IOException {
-                    return table_.getRow( irow_ );
-                }
-                public boolean next() {
-                    return ++irow_ < nrow_;
-                }
-                public void close() {
-                }
-            };
+                                   long irow, long nrow ) throws IOException {
+            super( spec, table.getRowAccess() );
             table_ = table;
+            racc_ = (RowAccess) rowdata_;
             irow_ = irow;
             nrow_ = nrow;
         }
@@ -247,7 +243,8 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
         public boolean next() {
             try {
                 while ( ! failed_ && irow_ < nrow_ - 1 ) {
-                    if ( reader_.getMaskFlag( rowseq_, ++irow_ ) ) {
+                    if ( reader_.getMaskFlag( racc_, ++irow_ ) ) {
+                        racc_.setRowIndex( irow_ );
                         return true;
                     }
                 }
@@ -261,8 +258,16 @@ public class SimpleDataStoreFactory implements DataStoreFactory, DataStore {
         public TupleSequence split() {
             if ( nrow_ - irow_ > 2 ) {
                 long mid = ( irow_ + nrow_ ) / 2;
-                TupleSequence split =
-                    new RandomSimpleTupleSequence( spec_, table_, irow_, mid );
+                TupleSequence split;
+                try {
+                    split = new RandomSimpleTupleSequence( spec_, table_,
+                                                           irow_, mid );
+                }
+                catch ( IOException e ) {
+                    logger_.log( Level.WARNING, "Error re-reading plot data",
+                                 e );
+                    return null;
+                }
                 irow_ = mid - 1;
                 return split;
             }
