@@ -99,7 +99,7 @@ public class ErrorArrayForm implements ShapeForm {
         thickKey_ = MultiPointForm.createThicknessKey( shapeKey_ );
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 0;
     }
 
@@ -129,7 +129,12 @@ public class ErrorArrayForm implements ShapeForm {
         return extraCoords_.clone();
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
