@@ -62,7 +62,7 @@ public class LineArrayForm implements ShapeForm {
         icYs_ = 1;
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 0;
     }
 
@@ -88,7 +88,12 @@ public class LineArrayForm implements ShapeForm {
         return new Coord[ 0 ];
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
