@@ -8,7 +8,6 @@ import java.util.WeakHashMap;
 import java.util.logging.Logger;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
-import uk.ac.starlink.table.TableScheme;
 import uk.ac.starlink.task.Environment;
 import uk.ac.starlink.task.Parameter;
 import uk.ac.starlink.task.ParameterValueException;
@@ -123,7 +122,7 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
         final StarTableFactory tfact;
         if ( sval == null || sval.trim().length() == 0 ||
              sval.equalsIgnoreCase( FILE_OPTION ) ) {
-            tfact = new StarTableFactory();
+            tfact = createDefaultTableFactory();
         }
         else if ( sval.toLowerCase().startsWith( DIRS_PREFIX ) ) {
             String dirlist = sval.substring( DIRS_PREFIX.length() );
@@ -148,9 +147,6 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
             throw new UsageException( "Unknown form; "
                                     + "should be dirs:* or locator:*" );
         }
-        for ( TableScheme scheme : Stilts.getStandardSchemes() ) {
-            tfact.addScheme( scheme );
-        }
         return tfact;
     }
 
@@ -164,6 +160,17 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
         return new LocatorStarTableFactory( locator );
     }
 
+    /**
+     * Returns a table factory with standard characteristics for STILTS.
+     *
+     * @return  new table factory
+     */
+    private static StarTableFactory createDefaultTableFactory() {
+        StarTableFactory tfact = new StarTableFactory();
+        Stilts.addStandardSchemes( tfact );
+        return tfact;
+    }
+
     /**
      * StarTableFactory implementation based on a TableLocator.
      */
@@ -212,7 +219,7 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
                 }
             }
             tableMap_ = new WeakHashMap<String,StarTable>();
-            tfact_ = new StarTableFactory();
+            tfact_ = createDefaultTableFactory();
         }
 
         public StarTable getTable( String location ) throws IOException {
@@ -229,6 +236,9 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
                     return tbl;
                 }
             }
+            if ( StarTableFactory.parseSchemeLocation( location ) != null ) {
+                return tfact_.makeStarTable( location );
+            }
             throw new FileNotFoundException( "No known table " + location );
         }
     }
