@@ -13,16 +13,22 @@ public class ResourceTest extends TestCase {
 
     public void testResources()
             throws IOException, SAXException, ParserConfigurationException {
-        for ( Map.Entry<String,URL> entry :
-              IvoaSchemaResolver.getSchemaMap().entrySet() ) {
+        int nSchema = 0;
+        Map<String,URL> schemaMap = new IvoaSchemaResolver().getSchemaMap();
+        for ( Map.Entry<String,URL> entry : schemaMap.entrySet() ) {
             String namespace = entry.getKey();
             URL url = entry.getValue();
             assertNotNull( "No resource for " + namespace, url );
-            if ( url != null ) {
+            if ( url != null &&
+                 IvoaSchemaResolver.IVOA_SCHEMA_MAP.containsKey( namespace ) ) {
                 assertEquals( "Wrong namespace for " + url,
                               namespace, getTargetNamespace( url ) );
             }
+            nSchema++;
         }
+        assertTrue( nSchema > 8 );
+        assertTrue( schemaMap.containsKey( IvoaSchemaResolver.UWS_URI ) );
+        assertTrue( schemaMap.containsKey( "http://www.w3.org/2001/XMLSchema"));
     }
 
     private String getTargetNamespace( URL schemaUrl )
