@@ -2,12 +2,12 @@ package uk.ac.starlink.ttools.task;
 
 import java.net.URL;
 import java.util.logging.Level;
-import java.util.logging.Logger;
 import junit.framework.TestCase;
 import uk.ac.starlink.table.RowRunner;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
+import uk.ac.starlink.util.LogUtils;
 import uk.ac.starlink.util.URLDataSource;
 
 public class CombinedMatchTest extends TestCase {
@@ -18,7 +18,7 @@ public class CombinedMatchTest extends TestCase {
     final StarTable tycho_;
 
     public CombinedMatchTest() throws Exception {
-        Logger.getLogger( "uk.ac.starlink" ).setLevel( Level.WARNING );
+        LogUtils.getLogger( "uk.ac.starlink" ).setLevel( Level.WARNING );
         StarTableFactory tf = new StarTableFactory( true );
         tmass_ = tf.makeStarTable( new URLDataSource( tmassLoc_ ) );
         tycho_ = tf.makeStarTable( new URLDataSource( tychoLoc_ ) );
