@@ -6,7 +6,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Arrays;
 import java.util.logging.Level;
-import java.util.logging.Logger;
 import uk.ac.starlink.fits.AbstractFitsTableWriter;
 import uk.ac.starlink.fits.FitsHeader;
 import uk.ac.starlink.fits.FitsTableWriter;
@@ -26,6 +25,7 @@ import uk.ac.starlink.ttools.convert.SkySystem;
 import uk.ac.starlink.ttools.convert.SkyUnits;
 import uk.ac.starlink.ttools.filter.ArgException;
 import uk.ac.starlink.ttools.filter.AssertException;
+import uk.ac.starlink.util.LogUtils;
 import uk.ac.starlink.votable.FitsPlusTableWriter;
 
 public class TablePipeTest extends TableTestCase {
@@ -42,14 +42,14 @@ public class TablePipeTest extends TableTestCase {
             col( "d", new String[] { "Mark", "Beauchamp", "Taylor", null, } ),
         } );
 
-        Logger.getLogger( "uk.ac.starlink.ttools.filter" )
-              .setLevel( Level.WARNING );
-        Logger.getLogger( "uk.ac.starlink.table.storage" )
-              .setLevel( Level.WARNING );
-        Logger.getLogger( "uk.ac.starlink.fits" )
-              .setLevel( Level.WARNING );
-        Logger.getLogger( "uk.ac.starlink.util" )
-              .setLevel( Level.WARNING );
+        LogUtils.getLogger( "uk.ac.starlink.ttools.filter" )
+                .setLevel( Level.SEVERE );
+        LogUtils.getLogger( "uk.ac.starlink.table.storage" )
+                .setLevel( Level.WARNING );
+        LogUtils.getLogger( "uk.ac.starlink.fits" )
+                .setLevel( Level.WARNING );
+        LogUtils.getLogger( "uk.ac.starlink.util" )
+                .setLevel( Level.WARNING );
     }
 
     private StarTable apply( String cmd ) throws Exception {
@@ -497,12 +497,17 @@ public class TablePipeTest extends TableTestCase {
 
     public void testFixNames() throws Exception {
         assertSameData( inTable_, apply( "fixcolnames" ) );
-        StarTable t1 = apply( "addcol 'a b c' 99" );
+        StarTable t1 = apply( "addcol 'a b c' 99;"
+                            + "addcol XX 20;"
+                            + "addcol xx 21" );
         t1.setParameter( new DescribedValue(
                              new DefaultValueInfo( "d e f", Integer.class ),
                              new Integer( 2112 ) ) );
         StarTable t2 = process( t1, "fixcolnames" );
-        assertEquals( "a_b_c", getColNames( t2 )[ inTable_.getColumnCount() ] );
+        int ncol0 = inTable_.getColumnCount();
+        assertEquals( "a_b_c", getColNames( t2 )[ ncol0 ] );
+        assertEquals( "XX", getColNames( t2 )[ ncol0 + 1 ] );
+        assertEquals( "xx_1", getColNames( t2 )[ ncol0 + 2 ] );
         assertEquals( new Integer( 2112 ),
                       t2.getParameterByName( "d_e_f" ).getValue() );
     }
